@@ -1,4 +1,4 @@
-__version__ = '0.2.1'
+__version__ = '0.2.2'
 __author__  = 'Putt Sakdhnagool <putt.sakdhnagool@nectec.or.th>'
 __license__ = 'MIT'
 
@@ -9,6 +9,6 @@ DEFAULT_DISPLAY_FIELDS=[
     "description",
     "remaining_percent",
     "allocation",
+    "used",
     "remaining",
-    "used"
 ]
